@@ -109,7 +109,7 @@
 		options(OutSep = ",")
 }
 
-.onLoad <- function (lib, pkg)
+.onAttach <- function (lib, pkg)
 {
 	## Make sure config is OK
 	.loadSvOptions()
@@ -158,11 +158,17 @@
 		}
 		
 		if (length(Komodo) == 0 || Komodo == "") {
-			Komodo <- try(suppressWarnings(system(
-				"locate --basename -e --regex ^komodo$ | grep -vF 'INSTALLDIR' | grep -F 'bin/komodo' | tail --lines=1",
-				intern = TRUE, ignore.stderr = TRUE)), silent = TRUE)
-			if (inherits(Komodo, "try-error")) Komodo <- NULL
-			#debugMsg("locate komodo", "returned", Komodo)
+			isLocate <- suppressWarnings(length(system('which locate',
+					intern = TRUE)) > 0)
+			if (!isLocate || isMac()) { # locate is not there or Mac OS X
+				Komodo <- NULL
+			} else {
+				Komodo <- try(suppressWarnings(system(
+					"locate --basename -e --regex ^komodo$ | grep -vF 'INSTALLDIR' | grep -F 'bin/komodo' | tail --lines=1",
+					intern = TRUE, ignore.stderr = TRUE)), silent = TRUE)
+				if (inherits(Komodo, "try-error")) Komodo <- NULL
+				#debugMsg("locate komodo", "returned", Komodo)
+			}
 		}
 		## Just to avoid warnings while compiling outside of Windows...
 		readRegistry <- function() return()
@@ -334,14 +340,14 @@
 
 		## Create a .Last.sys function that clears some variables in .GlobalEnv
 		## and then, switch to R.initdir before closing R. The function is
-		## stored in TempEnv()
+		## stored in SciViews:TempEnv
 		assignTemp(".Last.sys", function () {
 			## Eliminate some known hidden variables from .GlobalEnv to prevent
 			## saving them in the .RData file
 			if (exists(".required", envir = .GlobalEnv, inherits = FALSE))
 				rm(list = ".required", envir = .GlobalEnv, inherits = FALSE)
-			## Note: .SciViewsReady is now recorded in TempEnv() instead of
-			## .GlobalEnv, but we leave this code for old workspaces...
+			## Note: .SciViewsReady is now recorded in SciViews:TempEnv instead
+			## of .GlobalEnv, but we leave this code for old workspaces...
 			if (exists(".SciViewsReady", envir = .GlobalEnv, inherits = FALSE))
 				rm(list = ".SciViewsReady", envir = .GlobalEnv, inherits = FALSE)
 			## If a R.initdir is defined, make sure to switch to it, so that
